searchData={"items":[{"type":"module","title":"Holidex.Countries.Canada","doc":"Provides public holiday observances for Canadian holidays. Each province and territory in Canada has the authority to establish its own holiday schedule and observance rules.","ref":"Holidex.Countries.Canada.html"},{"type":"function","title":"Holidex.Countries.Canada.holiday/2","doc":"Generates a NationalHoliday struct for the specified holiday and year.\n\nThis function creates a NationalHoliday struct for the given holiday and year.\nIt also calculates the observance date, which may differ from the actual date\nif the holiday falls on a weekend or has special observance rules.","ref":"Holidex.Countries.Canada.html#holiday/2"},{"type":"function","title":"Parameters - Holidex.Countries.Canada.holiday/2","doc":"- holiday_name: Atom representing the holiday (e.g., :new_years_day, :labour_day)\n  - year: Integer representing the year for which to generate the holiday","ref":"Holidex.Countries.Canada.html#holiday/2-parameters"},{"type":"function","title":"Returns - Holidex.Countries.Canada.holiday/2","doc":"* `Holidex.NationalHoliday.t()`: A struct containing details about the holiday\n  * `{:error, :holiday, atom()}`: An error tuple if the input is invalid","ref":"Holidex.Countries.Canada.html#holiday/2-returns"},{"type":"function","title":"Examples - Holidex.Countries.Canada.holiday/2","doc":"iex> Holidex.Countries.Canada.holiday(:new_years_day, 2024)\n    %Holidex.NationalHoliday{\n      name: \"New Years Day\",\n      categories: [:national],\n      date: ~D[2024-01-01],\n      observance_date: ~D[2024-01-01],\n      regional_names: %{},\n      regions: [:ab, :bc, :mb, :nb, :nl, :nt, :ns, :nu, :on, :pe, :qc, :sk, :yt],\n      description: \"\",\n      country: :ca\n    }","ref":"Holidex.Countries.Canada.html#holiday/2-examples"},{"type":"function","title":"Holidex.Countries.Canada.holidays/1","doc":"Retrieves a list of national public holidays for the specified year.","ref":"Holidex.Countries.Canada.html#holidays/1"},{"type":"function","title":"Parameters - Holidex.Countries.Canada.holidays/1","doc":"* `year` - An integer representing the year for which to fetch holidays.","ref":"Holidex.Countries.Canada.html#holidays/1-parameters"},{"type":"function","title":"Returns - Holidex.Countries.Canada.holidays/1","doc":"* `{:ok, list(Holidex.NationalHoliday.t())}` - A tuple containing `:ok` and a list of\n    `Holidex.NationalHoliday` structs representing the public holidays for the given year.\n  * `{:error, atom(), String.t()}` - A tuple containing `:error`, the method called as a tuple,\n      and an error message string if the operation fails (e.g., invalid year, API failure, etc.).\n  * `{:error, String.t()}` - A tuple containing `:error` and an error message string if\n    the operation fails (e.g., invalid year, API failure, etc.).","ref":"Holidex.Countries.Canada.html#holidays/1-returns"},{"type":"function","title":"Examples - Holidex.Countries.Canada.holidays/1","doc":"iex> Holidex.Countries.Canada.holidays(2024)\n    {:ok, [%Holidex.NationalHoliday{name: \"New Year's Day\", date: ~D[2024-01-01]}, ...]}\n\n    iex> Holidex.Countries.Canada.holidays(1800)\n    {:error, :holidays, \"Year was out of range...\"}","ref":"Holidex.Countries.Canada.html#holidays/1-examples"},{"type":"function","title":"Holidex.Countries.Canada.holidays_by_region/2","doc":"Retrieves a list of national and regional holidays for a specific region and year.\n\nThis function fetches all observed national and regional holidays and will use localized\nholiday names if they're available. The nationally recognized name will appear beside\nit's regional counterpart in parenthesis.","ref":"Holidex.Countries.Canada.html#holidays_by_region/2"},{"type":"function","title":"Parameters - Holidex.Countries.Canada.holidays_by_region/2","doc":"- region_code: String or atom representing the region code (e.g., :on, :bc)\n  - year: Integer representing the year for which to retrieve holidays","ref":"Holidex.Countries.Canada.html#holidays_by_region/2-parameters"},{"type":"function","title":"Returns - Holidex.Countries.Canada.holidays_by_region/2","doc":"* `{:ok, [RegionalHoliday.t()]}`: A tuple containing a list of RegionalHoliday structs\n  * `{:error, atom()}`: An error tuple if the input is invalid or an error occurs during processing","ref":"Holidex.Countries.Canada.html#holidays_by_region/2-returns"},{"type":"function","title":"Examples - Holidex.Countries.Canada.holidays_by_region/2","doc":"iex> Holidex.Countries.Canada.holidays_by_region(:mb, 2024)\n    {:ok,\n     [\n       %Holidex.RegionalHoliday{\n         name: \"New Years Day\",\n         categories: [:national],\n         date: ~D[2024-01-01],\n         observance_date: ~D[2024-01-01],\n         region: :mb,\n         description: \"\",\n         country: :ca\n       },\n       %Holidex.RegionalHoliday{\n         name: \"Louis Riel Day (Family Day)\",\n         categories: [:regional],\n         date: ~D[2024-02-19],\n         observance_date: ~D[2024-02-19],\n         region: :mb,\n         description: \"\",\n         country: :ca\n       },\n       ...\n      ]\n\n    iex> Holidex.holidays_by_region(:invalid_region, 2024)\n    {:error, :holidays_by_region, :invalid_parameters}","ref":"Holidex.Countries.Canada.html#holidays_by_region/2-examples"},{"type":"function","title":"Holidex.Countries.Canada.region_codes/0","doc":"Retrieves a list of available region codes.\n\nThis function returns a list of region codes that can be used with other functions\nin the module to specify geographic regions for holiday data.","ref":"Holidex.Countries.Canada.html#region_codes/0"},{"type":"function","title":"Returns - Holidex.Countries.Canada.region_codes/0","doc":"* `list(region_code())` - A list of strings representing region codes.","ref":"Holidex.Countries.Canada.html#region_codes/0-returns"},{"type":"function","title":"Examples - Holidex.Countries.Canada.region_codes/0","doc":"iex> Holidex.Countries.Canada.region_codes()\n    [:ab, :bc, :mb, :nb, :nl, :nt, :ns, :nu, :on, :pe, :qc, :sk, :yt]","ref":"Holidex.Countries.Canada.html#region_codes/0-examples"},{"type":"function","title":"Holidex.Countries.Canada.regions/0","doc":"Retrieves detailed information about all available regions.\n\nThis function returns a list of maps, each containing detailed information\nabout a specific region, including its name, type, and region code.","ref":"Holidex.Countries.Canada.html#regions/0"},{"type":"function","title":"Returns - Holidex.Countries.Canada.regions/0","doc":"* `list(map())` - A list of maps, each representing a region with the following keys:\n    - `:name` - The name of the region (string)\n    - `:region_type` - The type of the region (atom, e.g., :province, :state)\n    - `:region_code` - The code for the region (atom)","ref":"Holidex.Countries.Canada.html#regions/0-returns"},{"type":"function","title":"Examples - Holidex.Countries.Canada.regions/0","doc":"iex> Holidex.Countries.Canada.regions()\n    [\n      %{name: \"Alberta\", region_type: :province, region_code: :ab},\n      %{name: \"British Columbia\", region_type: :province, region_code: :bc},\n      ...\n    ]","ref":"Holidex.Countries.Canada.html#regions/0-examples"},{"type":"type","title":"Holidex.Countries.Canada.holiday_name/0","doc":"An atom representing a supported holiday name.","ref":"Holidex.Countries.Canada.html#t:holiday_name/0"},{"type":"type","title":"Holidex.Countries.Canada.region_code/0","doc":"An atom representing a Province or Territory short code.","ref":"Holidex.Countries.Canada.html#t:region_code/0"},{"type":"type","title":"Holidex.Countries.Canada.year/0","doc":"","ref":"Holidex.Countries.Canada.html#t:year/0"},{"type":"module","title":"Holidex.DateCalculators.Easter","doc":"Provides calculations for Easter-related dates.","ref":"Holidex.DateCalculators.Easter.html"},{"type":"function","title":"Holidex.DateCalculators.Easter.new/1","doc":"Calculates Easter-related dates for a given year.\n\nReturns a struct containing the dates for Good Friday, Easter Sunday, and Easter Monday.","ref":"Holidex.DateCalculators.Easter.html#new/1"},{"type":"function","title":"Parameters - Holidex.DateCalculators.Easter.new/1","doc":"- `year`: The year for which to calculate Easter dates","ref":"Holidex.DateCalculators.Easter.html#new/1-parameters"},{"type":"function","title":"Examples - Holidex.DateCalculators.Easter.new/1","doc":"iex> Holidex.DateCalculators.Easter.new(2023)\n    %Holidex.DateCalculators.Easter{\n      year: 2023,\n      good_friday: ~D[2023-04-07],\n      easter_sunday: ~D[2023-04-09],\n      easter_monday: ~D[2023-04-10]\n    }","ref":"Holidex.DateCalculators.Easter.html#new/1-examples"},{"type":"type","title":"Holidex.DateCalculators.Easter.t/0","doc":"","ref":"Holidex.DateCalculators.Easter.html#t:t/0"},{"type":"module","title":"Holidex.NationalHoliday","doc":"Defines the structure of a national holiday.","ref":"Holidex.NationalHoliday.html"},{"type":"type","title":"Holidex.NationalHoliday.category/0","doc":"","ref":"Holidex.NationalHoliday.html#t:category/0"},{"type":"type","title":"Holidex.NationalHoliday.country_code/0","doc":"","ref":"Holidex.NationalHoliday.html#t:country_code/0"},{"type":"type","title":"Holidex.NationalHoliday.region/0","doc":"","ref":"Holidex.NationalHoliday.html#t:region/0"},{"type":"type","title":"Holidex.NationalHoliday.t/0","doc":"","ref":"Holidex.NationalHoliday.html#t:t/0"},{"type":"module","title":"Holidex.RegionalHoliday","doc":"Defines the structure of a regional holiday.","ref":"Holidex.RegionalHoliday.html"},{"type":"type","title":"Holidex.RegionalHoliday.category/0","doc":"","ref":"Holidex.RegionalHoliday.html#t:category/0"},{"type":"type","title":"Holidex.RegionalHoliday.country_code/0","doc":"","ref":"Holidex.RegionalHoliday.html#t:country_code/0"},{"type":"type","title":"Holidex.RegionalHoliday.region/0","doc":"","ref":"Holidex.RegionalHoliday.html#t:region/0"},{"type":"type","title":"Holidex.RegionalHoliday.t/0","doc":"","ref":"Holidex.RegionalHoliday.html#t:t/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}